vfbLib.typing.CustomCmap
========================

.. currentmodule:: vfbLib.typing

.. autoclass:: CustomCmap
   :members:
   :show-inheritance:
   :inherited-members:

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~CustomCmap.__init__
      ~CustomCmap.clear
      ~CustomCmap.copy
      ~CustomCmap.fromkeys
      ~CustomCmap.get
      ~CustomCmap.items
      ~CustomCmap.keys
      ~CustomCmap.pop
      ~CustomCmap.popitem
      ~CustomCmap.setdefault
      ~CustomCmap.update
      ~CustomCmap.values
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~CustomCmap.language_id
      ~CustomCmap.platform_id
      ~CustomCmap.encoding_id
      ~CustomCmap.format
      ~CustomCmap.option
      ~CustomCmap.records
   
   